==> microsoft.bingads-13.0.17-sources.jar: com/microsoft/bingads/v13/campaignmanagement/ArrayOfAudienceInfo.java <==

package com.microsoft.bingads.v13.campaignmanagement;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ArrayOfAudienceInfo complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ArrayOfAudienceInfo">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="AudienceInfo" type="{https://bingads.microsoft.com/CampaignManagement/v13}AudienceInfo" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ArrayOfAudienceInfo", propOrder = {
    "audienceInfos"
})
public class ArrayOfAudienceInfo {

    @XmlElement(name = "AudienceInfo", nillable = true)
    protected List<AudienceInfo> audienceInfos;

    /**
     * Gets the value of the audienceInfos property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the audienceInfos property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAudienceInfos().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AudienceInfo }
     * 
     * 
     * @return
     *     The value of the audienceInfos property.
     */
    public List<AudienceInfo> getAudienceInfos() {
        if (audienceInfos == null) {
            audienceInfos = new ArrayList<>();
        }
        return this.audienceInfos;
    }

}

==> microsoft.bingads-13.0.23-sources.jar: com/microsoft/bingads/v13/campaignmanagement/ArrayOfAudienceInfo.java <==

package com.microsoft.bingads.v13.campaignmanagement;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonCreator;

/**
 * <p>Java class for ArrayOfAudienceInfo complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ArrayOfAudienceInfo">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="AudienceInfo" type="{https://bingads.microsoft.com/CampaignManagement/v13}AudienceInfo" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ArrayOfAudienceInfo", propOrder = {
    "audienceInfos"
})
public class ArrayOfAudienceInfo {

    @XmlElement(name = "AudienceInfo", nillable = true)
    protected List<AudienceInfo> audienceInfos;
    public ArrayOfAudienceInfo()
    {
      this.audienceInfos = new ArrayList<AudienceInfo>();
    }
    @JsonCreator
    public ArrayOfAudienceInfo(List<AudienceInfo> audienceinfos)
    {
      this.audienceInfos = audienceinfos;
    }

    /**
     * Gets the value of the audienceInfos property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the audienceInfos property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAudienceInfos().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AudienceInfo }
     * 
     * 
     * @return
     *     The value of the audienceInfos property.
     */
    public List<AudienceInfo> getAudienceInfos() {
        if (audienceInfos == null) {
            audienceInfos = new ArrayList<>();
        }
        return this.audienceInfos;
    }

}
